/*
 * Created on Dec 28, 2005
 * Audiotester.java
 * 
 */
package com.mdp.voice;

import javax.sound.sampled.AudioFormat;
import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.DataLine;
import javax.sound.sampled.Mixer;
import javax.sound.sampled.SourceDataLine;
import javax.sound.sampled.TargetDataLine;

/**
 * Test program to help determine audio performance.
 * Not part of the CORE code.
 *  
 */
public class Audiotester {

    public static void main(String[] args) {

        Mixer.Info[] mixerInfo = AudioSystem.getMixerInfo();
        System.out.println("Available mixers:");

        for (int i = 0; i < mixerInfo.length; i++) {

            System.out.println(mixerInfo[ i].getName());

        }// end for loop        
        new Tester().doIt();

    }
}

class Tester {

    private SourceDataLine sourceDataLine;
    private TargetDataLine targetDataLine;
    private AudioFormat.Encoding encoding = AudioFormat.Encoding.PCM_SIGNED;
    private AudioFormat audioFormat;
    private float rate = 22050.0f;
    private int bufferSize = 10240 * 1;
    private int sampleSize = 16;
    private int channels = 1;
    private boolean bigEndian = true;
    private DataLine.Info info;

    public Tester() {
    }

    public void doIt() {

        try {
            DataLine.Info sourceLineInfo = new DataLine.Info(
                    SourceDataLine.class, getFormat(), bufferSize);

            sourceDataLine = (SourceDataLine) AudioSystem.getLine(sourceLineInfo);
            DataLine.Info targetLineInfo = new DataLine.Info(
                    TargetDataLine.class, getFormat(), bufferSize);

            targetDataLine = (TargetDataLine) AudioSystem.getLine(targetLineInfo);

            sourceDataLine.open();
            targetDataLine.open();

            sourceDataLine.start();
            targetDataLine.start();
            byte buffer[] = new byte[sourceDataLine.getBufferSize()];
            // System.out.println("Target is: " + targetDataLine.getBufferSize() );
            // System.out.println("Source is: " + sourceDataLine.getBufferSize() );
            while (true) {
                int read = targetDataLine.read(buffer, 0, buffer.length);
                // System.out.println( "Read..." + read );
                sourceDataLine.write(buffer, 0, read);

            }

        } catch (Exception e) {
            System.out.println("ex " + e.toString());
        }

    }

    private AudioFormat getFormat() {
        return new AudioFormat(encoding, rate, sampleSize, channels,
                (sampleSize / 8) * channels, rate, bigEndian);
    }
}
